# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/featureset/v1/featureset.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='github.com/metaprov/modelaapi/services/featureset/v1/featureset.proto',
  package='github.com.metaprov.modelaapi.services.featureset.v1',
  syntax='proto3',
  serialized_options=b'Z4github.com/metaprov/modelaapi/services/featureset/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nEgithub.com/metaprov/modelaapi/services/featureset/v1/featureset.proto\x12\x34github.com.metaprov.modelaapi.services.featureset.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x44github.com/metaprov/modelaapi/pkg/apis/data/v1alpha1/generated.proto\"\xc2\x01\n\x15ListFeaturesetRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12g\n\x06labels\x18\x02 \x03(\x0b\x32W.github.com.metaprov.modelaapi.services.featureset.v1.ListFeaturesetRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"m\n\x16ListFeaturesetResponse\x12S\n\x05items\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeaturesetList\"i\n\x17\x43reateFeaturesetRequest\x12N\n\x04item\x18\x01 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Featureset\"\x1a\n\x18\x43reateFeaturesetResponse\"i\n\x17UpdateFeaturesetRequest\x12N\n\x04item\x18\x01 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Featureset\"\x1a\n\x18UpdateFeaturesetResponse\"7\n\x14GetFeaturesetRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"u\n\x15GetFeaturesetResponse\x12N\n\x04item\x18\x01 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Featureset\x12\x0c\n\x04yaml\x18\x02 \x01(\t\":\n\x17\x44\x65leteFeaturesetRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x1a\n\x18\x44\x65leteFeaturesetResponse2\x97\x08\n\x11\x46\x65\x61turesetService\x12\xc5\x01\n\x0fListFeaturesets\x12K.github.com.metaprov.modelaapi.services.featureset.v1.ListFeaturesetRequest\x1aL.github.com.metaprov.modelaapi.services.featureset.v1.ListFeaturesetResponse\"\x17\x82\xd3\xe4\x93\x02\x11\x12\x0f/v1/featuresets\x12\xcd\x01\n\x10\x43reateFeatureset\x12M.github.com.metaprov.modelaapi.services.featureset.v1.CreateFeaturesetRequest\x1aN.github.com.metaprov.modelaapi.services.featureset.v1.CreateFeaturesetResponse\"\x1a\x82\xd3\xe4\x93\x02\x14\"\x0f/v1/featuresets:\x01*\x12\xc8\x01\n\rGetFeatureset\x12J.github.com.metaprov.modelaapi.services.featureset.v1.GetFeaturesetRequest\x1aK.github.com.metaprov.modelaapi.services.featureset.v1.GetFeaturesetResponse\"\x1e\x82\xd3\xe4\x93\x02\x18\x12\x16/v1/featuresets/{name}\x12\xe8\x01\n\x10UpdateFeatureset\x12M.github.com.metaprov.modelaapi.services.featureset.v1.UpdateFeaturesetRequest\x1aN.github.com.metaprov.modelaapi.services.featureset.v1.UpdateFeaturesetResponse\"5\x82\xd3\xe4\x93\x02/\x1a*/v1/featuresets/{featureset.metadata.name}:\x01*\x12\xb3\x01\n\x10\x44\x65leteFeatureset\x12M.github.com.metaprov.modelaapi.services.featureset.v1.DeleteFeaturesetRequest\x1aN.github.com.metaprov.modelaapi.services.featureset.v1.DeleteFeaturesetResponse\"\x00\x42\x36Z4github.com/metaprov/modelaapi/services/featureset/v1b\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2.DESCRIPTOR,])




_LISTFEATURESETREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='github.com.metaprov.modelaapi.services.featureset.v1.ListFeaturesetRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.featureset.v1.ListFeaturesetRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.featureset.v1.ListFeaturesetRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=377,
  serialized_end=422,
)

_LISTFEATURESETREQUEST = _descriptor.Descriptor(
  name='ListFeaturesetRequest',
  full_name='github.com.metaprov.modelaapi.services.featureset.v1.ListFeaturesetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.featureset.v1.ListFeaturesetRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='github.com.metaprov.modelaapi.services.featureset.v1.ListFeaturesetRequest.labels', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTFEATURESETREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=228,
  serialized_end=422,
)


_LISTFEATURESETRESPONSE = _descriptor.Descriptor(
  name='ListFeaturesetResponse',
  full_name='github.com.metaprov.modelaapi.services.featureset.v1.ListFeaturesetResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.featureset.v1.ListFeaturesetResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=424,
  serialized_end=533,
)


_CREATEFEATURESETREQUEST = _descriptor.Descriptor(
  name='CreateFeaturesetRequest',
  full_name='github.com.metaprov.modelaapi.services.featureset.v1.CreateFeaturesetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.featureset.v1.CreateFeaturesetRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=535,
  serialized_end=640,
)


_CREATEFEATURESETRESPONSE = _descriptor.Descriptor(
  name='CreateFeaturesetResponse',
  full_name='github.com.metaprov.modelaapi.services.featureset.v1.CreateFeaturesetResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=642,
  serialized_end=668,
)


_UPDATEFEATURESETREQUEST = _descriptor.Descriptor(
  name='UpdateFeaturesetRequest',
  full_name='github.com.metaprov.modelaapi.services.featureset.v1.UpdateFeaturesetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.featureset.v1.UpdateFeaturesetRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=670,
  serialized_end=775,
)


_UPDATEFEATURESETRESPONSE = _descriptor.Descriptor(
  name='UpdateFeaturesetResponse',
  full_name='github.com.metaprov.modelaapi.services.featureset.v1.UpdateFeaturesetResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=777,
  serialized_end=803,
)


_GETFEATURESETREQUEST = _descriptor.Descriptor(
  name='GetFeaturesetRequest',
  full_name='github.com.metaprov.modelaapi.services.featureset.v1.GetFeaturesetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.featureset.v1.GetFeaturesetRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.featureset.v1.GetFeaturesetRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=805,
  serialized_end=860,
)


_GETFEATURESETRESPONSE = _descriptor.Descriptor(
  name='GetFeaturesetResponse',
  full_name='github.com.metaprov.modelaapi.services.featureset.v1.GetFeaturesetResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.featureset.v1.GetFeaturesetResponse.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yaml', full_name='github.com.metaprov.modelaapi.services.featureset.v1.GetFeaturesetResponse.yaml', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=862,
  serialized_end=979,
)


_DELETEFEATURESETREQUEST = _descriptor.Descriptor(
  name='DeleteFeaturesetRequest',
  full_name='github.com.metaprov.modelaapi.services.featureset.v1.DeleteFeaturesetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.featureset.v1.DeleteFeaturesetRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.featureset.v1.DeleteFeaturesetRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=981,
  serialized_end=1039,
)


_DELETEFEATURESETRESPONSE = _descriptor.Descriptor(
  name='DeleteFeaturesetResponse',
  full_name='github.com.metaprov.modelaapi.services.featureset.v1.DeleteFeaturesetResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1041,
  serialized_end=1067,
)

_LISTFEATURESETREQUEST_LABELSENTRY.containing_type = _LISTFEATURESETREQUEST
_LISTFEATURESETREQUEST.fields_by_name['labels'].message_type = _LISTFEATURESETREQUEST_LABELSENTRY
_LISTFEATURESETRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._FEATURESETLIST
_CREATEFEATURESETREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._FEATURESET
_UPDATEFEATURESETREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._FEATURESET
_GETFEATURESETRESPONSE.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._FEATURESET
DESCRIPTOR.message_types_by_name['ListFeaturesetRequest'] = _LISTFEATURESETREQUEST
DESCRIPTOR.message_types_by_name['ListFeaturesetResponse'] = _LISTFEATURESETRESPONSE
DESCRIPTOR.message_types_by_name['CreateFeaturesetRequest'] = _CREATEFEATURESETREQUEST
DESCRIPTOR.message_types_by_name['CreateFeaturesetResponse'] = _CREATEFEATURESETRESPONSE
DESCRIPTOR.message_types_by_name['UpdateFeaturesetRequest'] = _UPDATEFEATURESETREQUEST
DESCRIPTOR.message_types_by_name['UpdateFeaturesetResponse'] = _UPDATEFEATURESETRESPONSE
DESCRIPTOR.message_types_by_name['GetFeaturesetRequest'] = _GETFEATURESETREQUEST
DESCRIPTOR.message_types_by_name['GetFeaturesetResponse'] = _GETFEATURESETRESPONSE
DESCRIPTOR.message_types_by_name['DeleteFeaturesetRequest'] = _DELETEFEATURESETREQUEST
DESCRIPTOR.message_types_by_name['DeleteFeaturesetResponse'] = _DELETEFEATURESETRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListFeaturesetRequest = _reflection.GeneratedProtocolMessageType('ListFeaturesetRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTFEATURESETREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.featureset.v1.featureset_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featureset.v1.ListFeaturesetRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTFEATURESETREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.featureset.v1.featureset_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featureset.v1.ListFeaturesetRequest)
  })
_sym_db.RegisterMessage(ListFeaturesetRequest)
_sym_db.RegisterMessage(ListFeaturesetRequest.LabelsEntry)

ListFeaturesetResponse = _reflection.GeneratedProtocolMessageType('ListFeaturesetResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTFEATURESETRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.featureset.v1.featureset_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featureset.v1.ListFeaturesetResponse)
  })
_sym_db.RegisterMessage(ListFeaturesetResponse)

CreateFeaturesetRequest = _reflection.GeneratedProtocolMessageType('CreateFeaturesetRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEFEATURESETREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.featureset.v1.featureset_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featureset.v1.CreateFeaturesetRequest)
  })
_sym_db.RegisterMessage(CreateFeaturesetRequest)

CreateFeaturesetResponse = _reflection.GeneratedProtocolMessageType('CreateFeaturesetResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEFEATURESETRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.featureset.v1.featureset_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featureset.v1.CreateFeaturesetResponse)
  })
_sym_db.RegisterMessage(CreateFeaturesetResponse)

UpdateFeaturesetRequest = _reflection.GeneratedProtocolMessageType('UpdateFeaturesetRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEFEATURESETREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.featureset.v1.featureset_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featureset.v1.UpdateFeaturesetRequest)
  })
_sym_db.RegisterMessage(UpdateFeaturesetRequest)

UpdateFeaturesetResponse = _reflection.GeneratedProtocolMessageType('UpdateFeaturesetResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEFEATURESETRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.featureset.v1.featureset_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featureset.v1.UpdateFeaturesetResponse)
  })
_sym_db.RegisterMessage(UpdateFeaturesetResponse)

GetFeaturesetRequest = _reflection.GeneratedProtocolMessageType('GetFeaturesetRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATURESETREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.featureset.v1.featureset_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featureset.v1.GetFeaturesetRequest)
  })
_sym_db.RegisterMessage(GetFeaturesetRequest)

GetFeaturesetResponse = _reflection.GeneratedProtocolMessageType('GetFeaturesetResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATURESETRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.featureset.v1.featureset_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featureset.v1.GetFeaturesetResponse)
  })
_sym_db.RegisterMessage(GetFeaturesetResponse)

DeleteFeaturesetRequest = _reflection.GeneratedProtocolMessageType('DeleteFeaturesetRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEFEATURESETREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.featureset.v1.featureset_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featureset.v1.DeleteFeaturesetRequest)
  })
_sym_db.RegisterMessage(DeleteFeaturesetRequest)

DeleteFeaturesetResponse = _reflection.GeneratedProtocolMessageType('DeleteFeaturesetResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEFEATURESETRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.featureset.v1.featureset_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featureset.v1.DeleteFeaturesetResponse)
  })
_sym_db.RegisterMessage(DeleteFeaturesetResponse)


DESCRIPTOR._options = None
_LISTFEATURESETREQUEST_LABELSENTRY._options = None

_FEATURESETSERVICE = _descriptor.ServiceDescriptor(
  name='FeaturesetService',
  full_name='github.com.metaprov.modelaapi.services.featureset.v1.FeaturesetService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1070,
  serialized_end=2117,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListFeaturesets',
    full_name='github.com.metaprov.modelaapi.services.featureset.v1.FeaturesetService.ListFeaturesets',
    index=0,
    containing_service=None,
    input_type=_LISTFEATURESETREQUEST,
    output_type=_LISTFEATURESETRESPONSE,
    serialized_options=b'\202\323\344\223\002\021\022\017/v1/featuresets',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateFeatureset',
    full_name='github.com.metaprov.modelaapi.services.featureset.v1.FeaturesetService.CreateFeatureset',
    index=1,
    containing_service=None,
    input_type=_CREATEFEATURESETREQUEST,
    output_type=_CREATEFEATURESETRESPONSE,
    serialized_options=b'\202\323\344\223\002\024\"\017/v1/featuresets:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetFeatureset',
    full_name='github.com.metaprov.modelaapi.services.featureset.v1.FeaturesetService.GetFeatureset',
    index=2,
    containing_service=None,
    input_type=_GETFEATURESETREQUEST,
    output_type=_GETFEATURESETRESPONSE,
    serialized_options=b'\202\323\344\223\002\030\022\026/v1/featuresets/{name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateFeatureset',
    full_name='github.com.metaprov.modelaapi.services.featureset.v1.FeaturesetService.UpdateFeatureset',
    index=3,
    containing_service=None,
    input_type=_UPDATEFEATURESETREQUEST,
    output_type=_UPDATEFEATURESETRESPONSE,
    serialized_options=b'\202\323\344\223\002/\032*/v1/featuresets/{featureset.metadata.name}:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteFeatureset',
    full_name='github.com.metaprov.modelaapi.services.featureset.v1.FeaturesetService.DeleteFeatureset',
    index=4,
    containing_service=None,
    input_type=_DELETEFEATURESETREQUEST,
    output_type=_DELETEFEATURESETRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_FEATURESETSERVICE)

DESCRIPTOR.services_by_name['FeaturesetService'] = _FEATURESETSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/datapipelinerun/v1/datapipelinerun.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='github.com/metaprov/modelaapi/services/datapipelinerun/v1/datapipelinerun.proto',
  package='github.com.metaprov.modelaapi.services.datapipelinerun.v1',
  syntax='proto3',
  serialized_options=b'Z9github.com/metaprov/modelaapi/services/datapipelinerun/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nOgithub.com/metaprov/modelaapi/services/datapipelinerun/v1/datapipelinerun.proto\x12\x39github.com.metaprov.modelaapi.services.datapipelinerun.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x44github.com/metaprov/modelaapi/pkg/apis/data/v1alpha1/generated.proto\"\xd1\x01\n\x1aListDataPipelineRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12q\n\x06labels\x18\x02 \x03(\x0b\x32\x61.github.com.metaprov.modelaapi.services.datapipelinerun.v1.ListDataPipelineRunRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"w\n\x1bListDataPipelineRunResponse\x12X\n\x05items\x18\x01 \x01(\x0b\x32I.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipelineRunList\"s\n\x1c\x43reateDataPipelineRunRequest\x12S\n\x04item\x18\x01 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipelineRun\"\x1f\n\x1d\x43reateDataPipelineRunResponse\"s\n\x1cUpdateDataPipelineRunRequest\x12S\n\x04item\x18\x01 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipelineRun\"\x1f\n\x1dUpdateDataPipelineRunResponse\"<\n\x19GetDataPipelineRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x7f\n\x1aGetDataPipelineRunResponse\x12S\n\x04item\x18\x01 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipelineRun\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"?\n\x1c\x44\x65leteDataPipelineRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x1f\n\x1d\x44\x65leteDataPipelineRunResponse\"\x1e\n\x1c\x41\x62ortDataPipelineRunResponse\">\n\x1b\x41\x62ortDataPipelineRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t2\xda\x0b\n\x16\x44\x61taPipelineRunService\x12\xe3\x01\n\x14ListDataPipelineRuns\x12U.github.com.metaprov.modelaapi.services.datapipelinerun.v1.ListDataPipelineRunRequest\x1aV.github.com.metaprov.modelaapi.services.datapipelinerun.v1.ListDataPipelineRunResponse\"\x1c\x82\xd3\xe4\x93\x02\x16\x12\x14/v1/datapipelineruns\x12\xeb\x01\n\x15\x43reateDataPipelineRun\x12W.github.com.metaprov.modelaapi.services.datapipelinerun.v1.CreateDataPipelineRunRequest\x1aX.github.com.metaprov.modelaapi.services.datapipelinerun.v1.CreateDataPipelineRunResponse\"\x1f\x82\xd3\xe4\x93\x02\x19\"\x14/v1/datapipelineruns:\x01*\x12\xe6\x01\n\x12GetDataPipelineRun\x12T.github.com.metaprov.modelaapi.services.datapipelinerun.v1.GetDataPipelineRunRequest\x1aU.github.com.metaprov.modelaapi.services.datapipelinerun.v1.GetDataPipelineRunResponse\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/v1/datapipelineruns/{name}\x12\x8b\x02\n\x15UpdateDataPipelineRun\x12W.github.com.metaprov.modelaapi.services.datapipelinerun.v1.UpdateDataPipelineRunRequest\x1aX.github.com.metaprov.modelaapi.services.datapipelinerun.v1.UpdateDataPipelineRunResponse\"?\x82\xd3\xe4\x93\x02\x39\x1a\x34/v1/datapipelineruns/{datapipelinerun.metadata.name}:\x01*\x12\xff\x01\n\x15\x44\x65leteDataPipelineRun\x12W.github.com.metaprov.modelaapi.services.datapipelinerun.v1.DeleteDataPipelineRunRequest\x1aX.github.com.metaprov.modelaapi.services.datapipelinerun.v1.DeleteDataPipelineRunResponse\"3\x82\xd3\xe4\x93\x02-*+/api/v1/datapipelineruns/{namespace}/{name}\x12\xf2\x01\n\x14\x41\x62ortDataPipelineRun\x12V.github.com.metaprov.modelaapi.services.datapipelinerun.v1.AbortDataPipelineRunRequest\x1aW.github.com.metaprov.modelaapi.services.datapipelinerun.v1.AbortDataPipelineRunResponse\")\x82\xd3\xe4\x93\x02#\"!/v1/datapipelineruns/{name}:abortB;Z9github.com/metaprov/modelaapi/services/datapipelinerun/v1b\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2.DESCRIPTOR,])




_LISTDATAPIPELINERUNREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='github.com.metaprov.modelaapi.services.datapipelinerun.v1.ListDataPipelineRunRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.datapipelinerun.v1.ListDataPipelineRunRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.datapipelinerun.v1.ListDataPipelineRunRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=407,
  serialized_end=452,
)

_LISTDATAPIPELINERUNREQUEST = _descriptor.Descriptor(
  name='ListDataPipelineRunRequest',
  full_name='github.com.metaprov.modelaapi.services.datapipelinerun.v1.ListDataPipelineRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.datapipelinerun.v1.ListDataPipelineRunRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='github.com.metaprov.modelaapi.services.datapipelinerun.v1.ListDataPipelineRunRequest.labels', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTDATAPIPELINERUNREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=243,
  serialized_end=452,
)


_LISTDATAPIPELINERUNRESPONSE = _descriptor.Descriptor(
  name='ListDataPipelineRunResponse',
  full_name='github.com.metaprov.modelaapi.services.datapipelinerun.v1.ListDataPipelineRunResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.datapipelinerun.v1.ListDataPipelineRunResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=454,
  serialized_end=573,
)


_CREATEDATAPIPELINERUNREQUEST = _descriptor.Descriptor(
  name='CreateDataPipelineRunRequest',
  full_name='github.com.metaprov.modelaapi.services.datapipelinerun.v1.CreateDataPipelineRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.datapipelinerun.v1.CreateDataPipelineRunRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=575,
  serialized_end=690,
)


_CREATEDATAPIPELINERUNRESPONSE = _descriptor.Descriptor(
  name='CreateDataPipelineRunResponse',
  full_name='github.com.metaprov.modelaapi.services.datapipelinerun.v1.CreateDataPipelineRunResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=692,
  serialized_end=723,
)


_UPDATEDATAPIPELINERUNREQUEST = _descriptor.Descriptor(
  name='UpdateDataPipelineRunRequest',
  full_name='github.com.metaprov.modelaapi.services.datapipelinerun.v1.UpdateDataPipelineRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.datapipelinerun.v1.UpdateDataPipelineRunRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=725,
  serialized_end=840,
)


_UPDATEDATAPIPELINERUNRESPONSE = _descriptor.Descriptor(
  name='UpdateDataPipelineRunResponse',
  full_name='github.com.metaprov.modelaapi.services.datapipelinerun.v1.UpdateDataPipelineRunResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=842,
  serialized_end=873,
)


_GETDATAPIPELINERUNREQUEST = _descriptor.Descriptor(
  name='GetDataPipelineRunRequest',
  full_name='github.com.metaprov.modelaapi.services.datapipelinerun.v1.GetDataPipelineRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.datapipelinerun.v1.GetDataPipelineRunRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.datapipelinerun.v1.GetDataPipelineRunRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=875,
  serialized_end=935,
)


_GETDATAPIPELINERUNRESPONSE = _descriptor.Descriptor(
  name='GetDataPipelineRunResponse',
  full_name='github.com.metaprov.modelaapi.services.datapipelinerun.v1.GetDataPipelineRunResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.datapipelinerun.v1.GetDataPipelineRunResponse.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yaml', full_name='github.com.metaprov.modelaapi.services.datapipelinerun.v1.GetDataPipelineRunResponse.yaml', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=937,
  serialized_end=1064,
)


_DELETEDATAPIPELINERUNREQUEST = _descriptor.Descriptor(
  name='DeleteDataPipelineRunRequest',
  full_name='github.com.metaprov.modelaapi.services.datapipelinerun.v1.DeleteDataPipelineRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.datapipelinerun.v1.DeleteDataPipelineRunRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.datapipelinerun.v1.DeleteDataPipelineRunRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1066,
  serialized_end=1129,
)


_DELETEDATAPIPELINERUNRESPONSE = _descriptor.Descriptor(
  name='DeleteDataPipelineRunResponse',
  full_name='github.com.metaprov.modelaapi.services.datapipelinerun.v1.DeleteDataPipelineRunResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1131,
  serialized_end=1162,
)


_ABORTDATAPIPELINERUNRESPONSE = _descriptor.Descriptor(
  name='AbortDataPipelineRunResponse',
  full_name='github.com.metaprov.modelaapi.services.datapipelinerun.v1.AbortDataPipelineRunResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1164,
  serialized_end=1194,
)


_ABORTDATAPIPELINERUNREQUEST = _descriptor.Descriptor(
  name='AbortDataPipelineRunRequest',
  full_name='github.com.metaprov.modelaapi.services.datapipelinerun.v1.AbortDataPipelineRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.datapipelinerun.v1.AbortDataPipelineRunRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.datapipelinerun.v1.AbortDataPipelineRunRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1196,
  serialized_end=1258,
)

_LISTDATAPIPELINERUNREQUEST_LABELSENTRY.containing_type = _LISTDATAPIPELINERUNREQUEST
_LISTDATAPIPELINERUNREQUEST.fields_by_name['labels'].message_type = _LISTDATAPIPELINERUNREQUEST_LABELSENTRY
_LISTDATAPIPELINERUNRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPIPELINERUNLIST
_CREATEDATAPIPELINERUNREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPIPELINERUN
_UPDATEDATAPIPELINERUNREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPIPELINERUN
_GETDATAPIPELINERUNRESPONSE.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPIPELINERUN
DESCRIPTOR.message_types_by_name['ListDataPipelineRunRequest'] = _LISTDATAPIPELINERUNREQUEST
DESCRIPTOR.message_types_by_name['ListDataPipelineRunResponse'] = _LISTDATAPIPELINERUNRESPONSE
DESCRIPTOR.message_types_by_name['CreateDataPipelineRunRequest'] = _CREATEDATAPIPELINERUNREQUEST
DESCRIPTOR.message_types_by_name['CreateDataPipelineRunResponse'] = _CREATEDATAPIPELINERUNRESPONSE
DESCRIPTOR.message_types_by_name['UpdateDataPipelineRunRequest'] = _UPDATEDATAPIPELINERUNREQUEST
DESCRIPTOR.message_types_by_name['UpdateDataPipelineRunResponse'] = _UPDATEDATAPIPELINERUNRESPONSE
DESCRIPTOR.message_types_by_name['GetDataPipelineRunRequest'] = _GETDATAPIPELINERUNREQUEST
DESCRIPTOR.message_types_by_name['GetDataPipelineRunResponse'] = _GETDATAPIPELINERUNRESPONSE
DESCRIPTOR.message_types_by_name['DeleteDataPipelineRunRequest'] = _DELETEDATAPIPELINERUNREQUEST
DESCRIPTOR.message_types_by_name['DeleteDataPipelineRunResponse'] = _DELETEDATAPIPELINERUNRESPONSE
DESCRIPTOR.message_types_by_name['AbortDataPipelineRunResponse'] = _ABORTDATAPIPELINERUNRESPONSE
DESCRIPTOR.message_types_by_name['AbortDataPipelineRunRequest'] = _ABORTDATAPIPELINERUNREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListDataPipelineRunRequest = _reflection.GeneratedProtocolMessageType('ListDataPipelineRunRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTDATAPIPELINERUNREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.datapipelinerun.v1.datapipelinerun_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datapipelinerun.v1.ListDataPipelineRunRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTDATAPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.datapipelinerun.v1.datapipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datapipelinerun.v1.ListDataPipelineRunRequest)
  })
_sym_db.RegisterMessage(ListDataPipelineRunRequest)
_sym_db.RegisterMessage(ListDataPipelineRunRequest.LabelsEntry)

ListDataPipelineRunResponse = _reflection.GeneratedProtocolMessageType('ListDataPipelineRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATAPIPELINERUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.datapipelinerun.v1.datapipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datapipelinerun.v1.ListDataPipelineRunResponse)
  })
_sym_db.RegisterMessage(ListDataPipelineRunResponse)

CreateDataPipelineRunRequest = _reflection.GeneratedProtocolMessageType('CreateDataPipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDATAPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.datapipelinerun.v1.datapipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datapipelinerun.v1.CreateDataPipelineRunRequest)
  })
_sym_db.RegisterMessage(CreateDataPipelineRunRequest)

CreateDataPipelineRunResponse = _reflection.GeneratedProtocolMessageType('CreateDataPipelineRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDATAPIPELINERUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.datapipelinerun.v1.datapipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datapipelinerun.v1.CreateDataPipelineRunResponse)
  })
_sym_db.RegisterMessage(CreateDataPipelineRunResponse)

UpdateDataPipelineRunRequest = _reflection.GeneratedProtocolMessageType('UpdateDataPipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDATAPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.datapipelinerun.v1.datapipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datapipelinerun.v1.UpdateDataPipelineRunRequest)
  })
_sym_db.RegisterMessage(UpdateDataPipelineRunRequest)

UpdateDataPipelineRunResponse = _reflection.GeneratedProtocolMessageType('UpdateDataPipelineRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDATAPIPELINERUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.datapipelinerun.v1.datapipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datapipelinerun.v1.UpdateDataPipelineRunResponse)
  })
_sym_db.RegisterMessage(UpdateDataPipelineRunResponse)

GetDataPipelineRunRequest = _reflection.GeneratedProtocolMessageType('GetDataPipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDATAPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.datapipelinerun.v1.datapipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datapipelinerun.v1.GetDataPipelineRunRequest)
  })
_sym_db.RegisterMessage(GetDataPipelineRunRequest)

GetDataPipelineRunResponse = _reflection.GeneratedProtocolMessageType('GetDataPipelineRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETDATAPIPELINERUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.datapipelinerun.v1.datapipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datapipelinerun.v1.GetDataPipelineRunResponse)
  })
_sym_db.RegisterMessage(GetDataPipelineRunResponse)

DeleteDataPipelineRunRequest = _reflection.GeneratedProtocolMessageType('DeleteDataPipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDATAPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.datapipelinerun.v1.datapipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datapipelinerun.v1.DeleteDataPipelineRunRequest)
  })
_sym_db.RegisterMessage(DeleteDataPipelineRunRequest)

DeleteDataPipelineRunResponse = _reflection.GeneratedProtocolMessageType('DeleteDataPipelineRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDATAPIPELINERUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.datapipelinerun.v1.datapipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datapipelinerun.v1.DeleteDataPipelineRunResponse)
  })
_sym_db.RegisterMessage(DeleteDataPipelineRunResponse)

AbortDataPipelineRunResponse = _reflection.GeneratedProtocolMessageType('AbortDataPipelineRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _ABORTDATAPIPELINERUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.datapipelinerun.v1.datapipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datapipelinerun.v1.AbortDataPipelineRunResponse)
  })
_sym_db.RegisterMessage(AbortDataPipelineRunResponse)

AbortDataPipelineRunRequest = _reflection.GeneratedProtocolMessageType('AbortDataPipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _ABORTDATAPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.datapipelinerun.v1.datapipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datapipelinerun.v1.AbortDataPipelineRunRequest)
  })
_sym_db.RegisterMessage(AbortDataPipelineRunRequest)


DESCRIPTOR._options = None
_LISTDATAPIPELINERUNREQUEST_LABELSENTRY._options = None

_DATAPIPELINERUNSERVICE = _descriptor.ServiceDescriptor(
  name='DataPipelineRunService',
  full_name='github.com.metaprov.modelaapi.services.datapipelinerun.v1.DataPipelineRunService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1261,
  serialized_end=2759,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListDataPipelineRuns',
    full_name='github.com.metaprov.modelaapi.services.datapipelinerun.v1.DataPipelineRunService.ListDataPipelineRuns',
    index=0,
    containing_service=None,
    input_type=_LISTDATAPIPELINERUNREQUEST,
    output_type=_LISTDATAPIPELINERUNRESPONSE,
    serialized_options=b'\202\323\344\223\002\026\022\024/v1/datapipelineruns',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateDataPipelineRun',
    full_name='github.com.metaprov.modelaapi.services.datapipelinerun.v1.DataPipelineRunService.CreateDataPipelineRun',
    index=1,
    containing_service=None,
    input_type=_CREATEDATAPIPELINERUNREQUEST,
    output_type=_CREATEDATAPIPELINERUNRESPONSE,
    serialized_options=b'\202\323\344\223\002\031\"\024/v1/datapipelineruns:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetDataPipelineRun',
    full_name='github.com.metaprov.modelaapi.services.datapipelinerun.v1.DataPipelineRunService.GetDataPipelineRun',
    index=2,
    containing_service=None,
    input_type=_GETDATAPIPELINERUNREQUEST,
    output_type=_GETDATAPIPELINERUNRESPONSE,
    serialized_options=b'\202\323\344\223\002\035\022\033/v1/datapipelineruns/{name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateDataPipelineRun',
    full_name='github.com.metaprov.modelaapi.services.datapipelinerun.v1.DataPipelineRunService.UpdateDataPipelineRun',
    index=3,
    containing_service=None,
    input_type=_UPDATEDATAPIPELINERUNREQUEST,
    output_type=_UPDATEDATAPIPELINERUNRESPONSE,
    serialized_options=b'\202\323\344\223\0029\0324/v1/datapipelineruns/{datapipelinerun.metadata.name}:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteDataPipelineRun',
    full_name='github.com.metaprov.modelaapi.services.datapipelinerun.v1.DataPipelineRunService.DeleteDataPipelineRun',
    index=4,
    containing_service=None,
    input_type=_DELETEDATAPIPELINERUNREQUEST,
    output_type=_DELETEDATAPIPELINERUNRESPONSE,
    serialized_options=b'\202\323\344\223\002-*+/api/v1/datapipelineruns/{namespace}/{name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AbortDataPipelineRun',
    full_name='github.com.metaprov.modelaapi.services.datapipelinerun.v1.DataPipelineRunService.AbortDataPipelineRun',
    index=5,
    containing_service=None,
    input_type=_ABORTDATAPIPELINERUNREQUEST,
    output_type=_ABORTDATAPIPELINERUNRESPONSE,
    serialized_options=b'\202\323\344\223\002#\"!/v1/datapipelineruns/{name}:abort',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_DATAPIPELINERUNSERVICE)

DESCRIPTOR.services_by_name['DataPipelineRunService'] = _DATAPIPELINERUNSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/apitoken/v1/apitoken.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.services.common.v1 import common_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='github.com/metaprov/modelaapi/services/apitoken/v1/apitoken.proto',
  package='github.com.metaprov.modelaapi.services.apitoken.v1',
  syntax='proto3',
  serialized_options=b'Z2github.com/metaprov/modelaapi/services/apitoken/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nAgithub.com/metaprov/modelaapi/services/apitoken/v1/apitoken.proto\x12\x32github.com.metaprov.modelaapi.services.apitoken.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x45github.com/metaprov/modelaapi/pkg/apis/infra/v1alpha1/generated.proto\x1a=github.com/metaprov/modelaapi/services/common/v1/common.proto\"\xbe\x01\n\x14ListApiTokensRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x64\n\x06labels\x18\x02 \x03(\x0b\x32T.github.com.metaprov.modelaapi.services.apitoken.v1.ListApiTokensRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"k\n\x15ListApiTokensResponse\x12R\n\x05items\x18\x01 \x01(\x0b\x32\x43.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.ApiTokenList\"\x12\n\x10\x41piTokenResponse\"x\n\x15\x43reateApiTokenRequest\x12M\n\x04item\x18\x01 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.ApiToken\x12\x10\n\x08password\x18\x02 \x01(\t\"\x18\n\x16\x43reateApiTokenResponse\"f\n\x15UpdateApiTokenRequest\x12M\n\x04item\x18\x01 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.ApiToken\"\x18\n\x16UpdateApiTokenResponse\"5\n\x12GetApiTokenRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"r\n\x13GetApiTokenResponse\x12M\n\x04item\x18\x01 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.ApiToken\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"?\n\x1cGetApiTokenNamespacesRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"t\n\x1dGetApiTokenNamespacesResponse\x12S\n\nnamespaces\x18\x01 \x03(\x0b\x32?.github.com.metaprov.modelaapi.services.common.v1.NamespaceInfo\"8\n\x15\x44\x65leteApiTokenRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x18\n\x16\x44\x65leteApiTokenResponse\"\x18\n\x16\x41piTokenCreateResponse\"\x10\n\x0eLogoutResponse\"\x17\n\x15ResetPasswordResponse\"I\n\x14\x41piTokenLoginRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08password\x18\x03 \x01(\t\"&\n\x15\x41piTokenLoginResponse\x12\r\n\x05token\x18\x01 \x01(\t\";\n\x18\x41piTokenGetByNameRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"&\n\x15\x41piTokenLogoutRequest\x12\r\n\x05token\x18\x01 \x01(\t\"h\n\x15\x43hangePasswordRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0b\n\x03old\x18\x03 \x01(\t\x12\x0b\n\x03new\x18\x04 \x01(\t\x12\x14\n\x0c\x63onfirmedNew\x18\x05 \x01(\t\"\x18\n\x16\x43hangePasswordResponse\"Z\n\x14ResetPasswordRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0b\n\x03new\x18\x03 \x01(\t\x12\x14\n\x0c\x63onfirmedNew\x18\x04 \x01(\t\"\x16\n\x14ResetPasswordReponse2\xc0\x08\n\x0f\x41piTokenService\x12\xbb\x01\n\rListApiTokens\x12H.github.com.metaprov.modelaapi.services.apitoken.v1.ListApiTokensRequest\x1aI.github.com.metaprov.modelaapi.services.apitoken.v1.ListApiTokensResponse\"\x15\x82\xd3\xe4\x93\x02\x0f\x12\r/v1/apitokens\x12\xc8\x01\n\x0e\x43reateApiToken\x12I.github.com.metaprov.modelaapi.services.apitoken.v1.CreateApiTokenRequest\x1aJ.github.com.metaprov.modelaapi.services.apitoken.v1.CreateApiTokenResponse\"\x1f\x82\xd3\xe4\x93\x02\x19\"\r/v1/apitokens:\x08\x61pitoken\x12\xc8\x01\n\x0bGetApiToken\x12\x46.github.com.metaprov.modelaapi.services.apitoken.v1.GetApiTokenRequest\x1aG.github.com.metaprov.modelaapi.services.apitoken.v1.GetApiTokenResponse\"(\x82\xd3\xe4\x93\x02\"\x12 /v1/{namespace}/apitokens/{name}\x12\x80\x02\n\x0eUpdateApiToken\x12I.github.com.metaprov.modelaapi.services.apitoken.v1.UpdateApiTokenRequest\x1aJ.github.com.metaprov.modelaapi.services.apitoken.v1.UpdateApiTokenResponse\"W\x82\xd3\xe4\x93\x02Q\x1a\x45/v1/{apitoken.metadata.namespace}/apitokens//{apitoken.metadata.name}:\x08\x61pitoken\x12\xd5\x01\n\x0e\x44\x65leteApiToken\x12I.github.com.metaprov.modelaapi.services.apitoken.v1.DeleteApiTokenRequest\x1aJ.github.com.metaprov.modelaapi.services.apitoken.v1.DeleteApiTokenResponse\",\x82\xd3\xe4\x93\x02&*$/api/{namespace}/v1/apitokens/{name}B4Z2github.com/metaprov/modelaapi/services/apitoken/v1b\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2.DESCRIPTOR,github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2.DESCRIPTOR,])




_LISTAPITOKENSREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='github.com.metaprov.modelaapi.services.apitoken.v1.ListApiTokensRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.apitoken.v1.ListApiTokensRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.apitoken.v1.ListApiTokensRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=431,
  serialized_end=476,
)

_LISTAPITOKENSREQUEST = _descriptor.Descriptor(
  name='ListApiTokensRequest',
  full_name='github.com.metaprov.modelaapi.services.apitoken.v1.ListApiTokensRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.apitoken.v1.ListApiTokensRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='github.com.metaprov.modelaapi.services.apitoken.v1.ListApiTokensRequest.labels', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTAPITOKENSREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=286,
  serialized_end=476,
)


_LISTAPITOKENSRESPONSE = _descriptor.Descriptor(
  name='ListApiTokensResponse',
  full_name='github.com.metaprov.modelaapi.services.apitoken.v1.ListApiTokensResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.apitoken.v1.ListApiTokensResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=478,
  serialized_end=585,
)


_APITOKENRESPONSE = _descriptor.Descriptor(
  name='ApiTokenResponse',
  full_name='github.com.metaprov.modelaapi.services.apitoken.v1.ApiTokenResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=587,
  serialized_end=605,
)


_CREATEAPITOKENREQUEST = _descriptor.Descriptor(
  name='CreateApiTokenRequest',
  full_name='github.com.metaprov.modelaapi.services.apitoken.v1.CreateApiTokenRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.apitoken.v1.CreateApiTokenRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='password', full_name='github.com.metaprov.modelaapi.services.apitoken.v1.CreateApiTokenRequest.password', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=607,
  serialized_end=727,
)


_CREATEAPITOKENRESPONSE = _descriptor.Descriptor(
  name='CreateApiTokenResponse',
  full_name='github.com.metaprov.modelaapi.services.apitoken.v1.CreateApiTokenResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=729,
  serialized_end=753,
)


_UPDATEAPITOKENREQUEST = _descriptor.Descriptor(
  name='UpdateApiTokenRequest',
  full_name='github.com.metaprov.modelaapi.services.apitoken.v1.UpdateApiTokenRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.apitoken.v1.UpdateApiTokenRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=755,
  serialized_end=857,
)


_UPDATEAPITOKENRESPONSE = _descriptor.Descriptor(
  name='UpdateApiTokenResponse',
  full_name='github.com.metaprov.modelaapi.services.apitoken.v1.UpdateApiTokenResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=859,
  serialized_end=883,
)


_GETAPITOKENREQUEST = _descriptor.Descriptor(
  name='GetApiTokenRequest',
  full_name='github.com.metaprov.modelaapi.services.apitoken.v1.GetApiTokenRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.apitoken.v1.GetApiTokenRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.apitoken.v1.GetApiTokenRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=885,
  serialized_end=938,
)


_GETAPITOKENRESPONSE = _descriptor.Descriptor(
  name='GetApiTokenResponse',
  full_name='github.com.metaprov.modelaapi.services.apitoken.v1.GetApiTokenResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.apitoken.v1.GetApiTokenResponse.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yaml', full_name='github.com.metaprov.modelaapi.services.apitoken.v1.GetApiTokenResponse.yaml', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=940,
  serialized_end=1054,
)


_GETAPITOKENNAMESPACESREQUEST = _descriptor.Descriptor(
  name='GetApiTokenNamespacesRequest',
  full_name='github.com.metaprov.modelaapi.services.apitoken.v1.GetApiTokenNamespacesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.apitoken.v1.GetApiTokenNamespacesRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.apitoken.v1.GetApiTokenNamespacesRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1056,
  serialized_end=1119,
)


_GETAPITOKENNAMESPACESRESPONSE = _descriptor.Descriptor(
  name='GetApiTokenNamespacesResponse',
  full_name='github.com.metaprov.modelaapi.services.apitoken.v1.GetApiTokenNamespacesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespaces', full_name='github.com.metaprov.modelaapi.services.apitoken.v1.GetApiTokenNamespacesResponse.namespaces', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1121,
  serialized_end=1237,
)


_DELETEAPITOKENREQUEST = _descriptor.Descriptor(
  name='DeleteApiTokenRequest',
  full_name='github.com.metaprov.modelaapi.services.apitoken.v1.DeleteApiTokenRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.apitoken.v1.DeleteApiTokenRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.apitoken.v1.DeleteApiTokenRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1239,
  serialized_end=1295,
)


_DELETEAPITOKENRESPONSE = _descriptor.Descriptor(
  name='DeleteApiTokenResponse',
  full_name='github.com.metaprov.modelaapi.services.apitoken.v1.DeleteApiTokenResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1297,
  serialized_end=1321,
)


_APITOKENCREATERESPONSE = _descriptor.Descriptor(
  name='ApiTokenCreateResponse',
  full_name='github.com.metaprov.modelaapi.services.apitoken.v1.ApiTokenCreateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1323,
  serialized_end=1347,
)


_LOGOUTRESPONSE = _descriptor.Descriptor(
  name='LogoutResponse',
  full_name='github.com.metaprov.modelaapi.services.apitoken.v1.LogoutResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1349,
  serialized_end=1365,
)


_RESETPASSWORDRESPONSE = _descriptor.Descriptor(
  name='ResetPasswordResponse',
  full_name='github.com.metaprov.modelaapi.services.apitoken.v1.ResetPasswordResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1367,
  serialized_end=1390,
)


_APITOKENLOGINREQUEST = _descriptor.Descriptor(
  name='ApiTokenLoginRequest',
  full_name='github.com.metaprov.modelaapi.services.apitoken.v1.ApiTokenLoginRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.apitoken.v1.ApiTokenLoginRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.apitoken.v1.ApiTokenLoginRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='password', full_name='github.com.metaprov.modelaapi.services.apitoken.v1.ApiTokenLoginRequest.password', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1392,
  serialized_end=1465,
)


_APITOKENLOGINRESPONSE = _descriptor.Descriptor(
  name='ApiTokenLoginResponse',
  full_name='github.com.metaprov.modelaapi.services.apitoken.v1.ApiTokenLoginResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='token', full_name='github.com.metaprov.modelaapi.services.apitoken.v1.ApiTokenLoginResponse.token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1467,
  serialized_end=1505,
)


_APITOKENGETBYNAMEREQUEST = _descriptor.Descriptor(
  name='ApiTokenGetByNameRequest',
  full_name='github.com.metaprov.modelaapi.services.apitoken.v1.ApiTokenGetByNameRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.apitoken.v1.ApiTokenGetByNameRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.apitoken.v1.ApiTokenGetByNameRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1507,
  serialized_end=1566,
)


_APITOKENLOGOUTREQUEST = _descriptor.Descriptor(
  name='ApiTokenLogoutRequest',
  full_name='github.com.metaprov.modelaapi.services.apitoken.v1.ApiTokenLogoutRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='token', full_name='github.com.metaprov.modelaapi.services.apitoken.v1.ApiTokenLogoutRequest.token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1568,
  serialized_end=1606,
)


_CHANGEPASSWORDREQUEST = _descriptor.Descriptor(
  name='ChangePasswordRequest',
  full_name='github.com.metaprov.modelaapi.services.apitoken.v1.ChangePasswordRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.apitoken.v1.ChangePasswordRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.apitoken.v1.ChangePasswordRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='old', full_name='github.com.metaprov.modelaapi.services.apitoken.v1.ChangePasswordRequest.old', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='new', full_name='github.com.metaprov.modelaapi.services.apitoken.v1.ChangePasswordRequest.new', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='confirmedNew', full_name='github.com.metaprov.modelaapi.services.apitoken.v1.ChangePasswordRequest.confirmedNew', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1608,
  serialized_end=1712,
)


_CHANGEPASSWORDRESPONSE = _descriptor.Descriptor(
  name='ChangePasswordResponse',
  full_name='github.com.metaprov.modelaapi.services.apitoken.v1.ChangePasswordResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1714,
  serialized_end=1738,
)


_RESETPASSWORDREQUEST = _descriptor.Descriptor(
  name='ResetPasswordRequest',
  full_name='github.com.metaprov.modelaapi.services.apitoken.v1.ResetPasswordRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.apitoken.v1.ResetPasswordRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.apitoken.v1.ResetPasswordRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='new', full_name='github.com.metaprov.modelaapi.services.apitoken.v1.ResetPasswordRequest.new', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='confirmedNew', full_name='github.com.metaprov.modelaapi.services.apitoken.v1.ResetPasswordRequest.confirmedNew', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1740,
  serialized_end=1830,
)


_RESETPASSWORDREPONSE = _descriptor.Descriptor(
  name='ResetPasswordReponse',
  full_name='github.com.metaprov.modelaapi.services.apitoken.v1.ResetPasswordReponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1832,
  serialized_end=1854,
)

_LISTAPITOKENSREQUEST_LABELSENTRY.containing_type = _LISTAPITOKENSREQUEST
_LISTAPITOKENSREQUEST.fields_by_name['labels'].message_type = _LISTAPITOKENSREQUEST_LABELSENTRY
_LISTAPITOKENSRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._APITOKENLIST
_CREATEAPITOKENREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._APITOKEN
_UPDATEAPITOKENREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._APITOKEN
_GETAPITOKENRESPONSE.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._APITOKEN
_GETAPITOKENNAMESPACESRESPONSE.fields_by_name['namespaces'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2._NAMESPACEINFO
DESCRIPTOR.message_types_by_name['ListApiTokensRequest'] = _LISTAPITOKENSREQUEST
DESCRIPTOR.message_types_by_name['ListApiTokensResponse'] = _LISTAPITOKENSRESPONSE
DESCRIPTOR.message_types_by_name['ApiTokenResponse'] = _APITOKENRESPONSE
DESCRIPTOR.message_types_by_name['CreateApiTokenRequest'] = _CREATEAPITOKENREQUEST
DESCRIPTOR.message_types_by_name['CreateApiTokenResponse'] = _CREATEAPITOKENRESPONSE
DESCRIPTOR.message_types_by_name['UpdateApiTokenRequest'] = _UPDATEAPITOKENREQUEST
DESCRIPTOR.message_types_by_name['UpdateApiTokenResponse'] = _UPDATEAPITOKENRESPONSE
DESCRIPTOR.message_types_by_name['GetApiTokenRequest'] = _GETAPITOKENREQUEST
DESCRIPTOR.message_types_by_name['GetApiTokenResponse'] = _GETAPITOKENRESPONSE
DESCRIPTOR.message_types_by_name['GetApiTokenNamespacesRequest'] = _GETAPITOKENNAMESPACESREQUEST
DESCRIPTOR.message_types_by_name['GetApiTokenNamespacesResponse'] = _GETAPITOKENNAMESPACESRESPONSE
DESCRIPTOR.message_types_by_name['DeleteApiTokenRequest'] = _DELETEAPITOKENREQUEST
DESCRIPTOR.message_types_by_name['DeleteApiTokenResponse'] = _DELETEAPITOKENRESPONSE
DESCRIPTOR.message_types_by_name['ApiTokenCreateResponse'] = _APITOKENCREATERESPONSE
DESCRIPTOR.message_types_by_name['LogoutResponse'] = _LOGOUTRESPONSE
DESCRIPTOR.message_types_by_name['ResetPasswordResponse'] = _RESETPASSWORDRESPONSE
DESCRIPTOR.message_types_by_name['ApiTokenLoginRequest'] = _APITOKENLOGINREQUEST
DESCRIPTOR.message_types_by_name['ApiTokenLoginResponse'] = _APITOKENLOGINRESPONSE
DESCRIPTOR.message_types_by_name['ApiTokenGetByNameRequest'] = _APITOKENGETBYNAMEREQUEST
DESCRIPTOR.message_types_by_name['ApiTokenLogoutRequest'] = _APITOKENLOGOUTREQUEST
DESCRIPTOR.message_types_by_name['ChangePasswordRequest'] = _CHANGEPASSWORDREQUEST
DESCRIPTOR.message_types_by_name['ChangePasswordResponse'] = _CHANGEPASSWORDRESPONSE
DESCRIPTOR.message_types_by_name['ResetPasswordRequest'] = _RESETPASSWORDREQUEST
DESCRIPTOR.message_types_by_name['ResetPasswordReponse'] = _RESETPASSWORDREPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListApiTokensRequest = _reflection.GeneratedProtocolMessageType('ListApiTokensRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTAPITOKENSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.apitoken.v1.apitoken_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.apitoken.v1.ListApiTokensRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTAPITOKENSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.apitoken.v1.apitoken_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.apitoken.v1.ListApiTokensRequest)
  })
_sym_db.RegisterMessage(ListApiTokensRequest)
_sym_db.RegisterMessage(ListApiTokensRequest.LabelsEntry)

ListApiTokensResponse = _reflection.GeneratedProtocolMessageType('ListApiTokensResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTAPITOKENSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.apitoken.v1.apitoken_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.apitoken.v1.ListApiTokensResponse)
  })
_sym_db.RegisterMessage(ListApiTokensResponse)

ApiTokenResponse = _reflection.GeneratedProtocolMessageType('ApiTokenResponse', (_message.Message,), {
  'DESCRIPTOR' : _APITOKENRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.apitoken.v1.apitoken_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.apitoken.v1.ApiTokenResponse)
  })
_sym_db.RegisterMessage(ApiTokenResponse)

CreateApiTokenRequest = _reflection.GeneratedProtocolMessageType('CreateApiTokenRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEAPITOKENREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.apitoken.v1.apitoken_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.apitoken.v1.CreateApiTokenRequest)
  })
_sym_db.RegisterMessage(CreateApiTokenRequest)

CreateApiTokenResponse = _reflection.GeneratedProtocolMessageType('CreateApiTokenResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEAPITOKENRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.apitoken.v1.apitoken_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.apitoken.v1.CreateApiTokenResponse)
  })
_sym_db.RegisterMessage(CreateApiTokenResponse)

UpdateApiTokenRequest = _reflection.GeneratedProtocolMessageType('UpdateApiTokenRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEAPITOKENREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.apitoken.v1.apitoken_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.apitoken.v1.UpdateApiTokenRequest)
  })
_sym_db.RegisterMessage(UpdateApiTokenRequest)

UpdateApiTokenResponse = _reflection.GeneratedProtocolMessageType('UpdateApiTokenResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEAPITOKENRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.apitoken.v1.apitoken_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.apitoken.v1.UpdateApiTokenResponse)
  })
_sym_db.RegisterMessage(UpdateApiTokenResponse)

GetApiTokenRequest = _reflection.GeneratedProtocolMessageType('GetApiTokenRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETAPITOKENREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.apitoken.v1.apitoken_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.apitoken.v1.GetApiTokenRequest)
  })
_sym_db.RegisterMessage(GetApiTokenRequest)

GetApiTokenResponse = _reflection.GeneratedProtocolMessageType('GetApiTokenResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETAPITOKENRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.apitoken.v1.apitoken_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.apitoken.v1.GetApiTokenResponse)
  })
_sym_db.RegisterMessage(GetApiTokenResponse)

GetApiTokenNamespacesRequest = _reflection.GeneratedProtocolMessageType('GetApiTokenNamespacesRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETAPITOKENNAMESPACESREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.apitoken.v1.apitoken_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.apitoken.v1.GetApiTokenNamespacesRequest)
  })
_sym_db.RegisterMessage(GetApiTokenNamespacesRequest)

GetApiTokenNamespacesResponse = _reflection.GeneratedProtocolMessageType('GetApiTokenNamespacesResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETAPITOKENNAMESPACESRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.apitoken.v1.apitoken_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.apitoken.v1.GetApiTokenNamespacesResponse)
  })
_sym_db.RegisterMessage(GetApiTokenNamespacesResponse)

DeleteApiTokenRequest = _reflection.GeneratedProtocolMessageType('DeleteApiTokenRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEAPITOKENREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.apitoken.v1.apitoken_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.apitoken.v1.DeleteApiTokenRequest)
  })
_sym_db.RegisterMessage(DeleteApiTokenRequest)

DeleteApiTokenResponse = _reflection.GeneratedProtocolMessageType('DeleteApiTokenResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEAPITOKENRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.apitoken.v1.apitoken_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.apitoken.v1.DeleteApiTokenResponse)
  })
_sym_db.RegisterMessage(DeleteApiTokenResponse)

ApiTokenCreateResponse = _reflection.GeneratedProtocolMessageType('ApiTokenCreateResponse', (_message.Message,), {
  'DESCRIPTOR' : _APITOKENCREATERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.apitoken.v1.apitoken_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.apitoken.v1.ApiTokenCreateResponse)
  })
_sym_db.RegisterMessage(ApiTokenCreateResponse)

LogoutResponse = _reflection.GeneratedProtocolMessageType('LogoutResponse', (_message.Message,), {
  'DESCRIPTOR' : _LOGOUTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.apitoken.v1.apitoken_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.apitoken.v1.LogoutResponse)
  })
_sym_db.RegisterMessage(LogoutResponse)

ResetPasswordResponse = _reflection.GeneratedProtocolMessageType('ResetPasswordResponse', (_message.Message,), {
  'DESCRIPTOR' : _RESETPASSWORDRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.apitoken.v1.apitoken_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.apitoken.v1.ResetPasswordResponse)
  })
_sym_db.RegisterMessage(ResetPasswordResponse)

ApiTokenLoginRequest = _reflection.GeneratedProtocolMessageType('ApiTokenLoginRequest', (_message.Message,), {
  'DESCRIPTOR' : _APITOKENLOGINREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.apitoken.v1.apitoken_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.apitoken.v1.ApiTokenLoginRequest)
  })
_sym_db.RegisterMessage(ApiTokenLoginRequest)

ApiTokenLoginResponse = _reflection.GeneratedProtocolMessageType('ApiTokenLoginResponse', (_message.Message,), {
  'DESCRIPTOR' : _APITOKENLOGINRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.apitoken.v1.apitoken_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.apitoken.v1.ApiTokenLoginResponse)
  })
_sym_db.RegisterMessage(ApiTokenLoginResponse)

ApiTokenGetByNameRequest = _reflection.GeneratedProtocolMessageType('ApiTokenGetByNameRequest', (_message.Message,), {
  'DESCRIPTOR' : _APITOKENGETBYNAMEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.apitoken.v1.apitoken_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.apitoken.v1.ApiTokenGetByNameRequest)
  })
_sym_db.RegisterMessage(ApiTokenGetByNameRequest)

ApiTokenLogoutRequest = _reflection.GeneratedProtocolMessageType('ApiTokenLogoutRequest', (_message.Message,), {
  'DESCRIPTOR' : _APITOKENLOGOUTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.apitoken.v1.apitoken_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.apitoken.v1.ApiTokenLogoutRequest)
  })
_sym_db.RegisterMessage(ApiTokenLogoutRequest)

ChangePasswordRequest = _reflection.GeneratedProtocolMessageType('ChangePasswordRequest', (_message.Message,), {
  'DESCRIPTOR' : _CHANGEPASSWORDREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.apitoken.v1.apitoken_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.apitoken.v1.ChangePasswordRequest)
  })
_sym_db.RegisterMessage(ChangePasswordRequest)

ChangePasswordResponse = _reflection.GeneratedProtocolMessageType('ChangePasswordResponse', (_message.Message,), {
  'DESCRIPTOR' : _CHANGEPASSWORDRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.apitoken.v1.apitoken_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.apitoken.v1.ChangePasswordResponse)
  })
_sym_db.RegisterMessage(ChangePasswordResponse)

ResetPasswordRequest = _reflection.GeneratedProtocolMessageType('ResetPasswordRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESETPASSWORDREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.apitoken.v1.apitoken_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.apitoken.v1.ResetPasswordRequest)
  })
_sym_db.RegisterMessage(ResetPasswordRequest)

ResetPasswordReponse = _reflection.GeneratedProtocolMessageType('ResetPasswordReponse', (_message.Message,), {
  'DESCRIPTOR' : _RESETPASSWORDREPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.apitoken.v1.apitoken_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.apitoken.v1.ResetPasswordReponse)
  })
_sym_db.RegisterMessage(ResetPasswordReponse)


DESCRIPTOR._options = None
_LISTAPITOKENSREQUEST_LABELSENTRY._options = None

_APITOKENSERVICE = _descriptor.ServiceDescriptor(
  name='ApiTokenService',
  full_name='github.com.metaprov.modelaapi.services.apitoken.v1.ApiTokenService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1857,
  serialized_end=2945,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListApiTokens',
    full_name='github.com.metaprov.modelaapi.services.apitoken.v1.ApiTokenService.ListApiTokens',
    index=0,
    containing_service=None,
    input_type=_LISTAPITOKENSREQUEST,
    output_type=_LISTAPITOKENSRESPONSE,
    serialized_options=b'\202\323\344\223\002\017\022\r/v1/apitokens',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateApiToken',
    full_name='github.com.metaprov.modelaapi.services.apitoken.v1.ApiTokenService.CreateApiToken',
    index=1,
    containing_service=None,
    input_type=_CREATEAPITOKENREQUEST,
    output_type=_CREATEAPITOKENRESPONSE,
    serialized_options=b'\202\323\344\223\002\031\"\r/v1/apitokens:\010apitoken',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetApiToken',
    full_name='github.com.metaprov.modelaapi.services.apitoken.v1.ApiTokenService.GetApiToken',
    index=2,
    containing_service=None,
    input_type=_GETAPITOKENREQUEST,
    output_type=_GETAPITOKENRESPONSE,
    serialized_options=b'\202\323\344\223\002\"\022 /v1/{namespace}/apitokens/{name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateApiToken',
    full_name='github.com.metaprov.modelaapi.services.apitoken.v1.ApiTokenService.UpdateApiToken',
    index=3,
    containing_service=None,
    input_type=_UPDATEAPITOKENREQUEST,
    output_type=_UPDATEAPITOKENRESPONSE,
    serialized_options=b'\202\323\344\223\002Q\032E/v1/{apitoken.metadata.namespace}/apitokens//{apitoken.metadata.name}:\010apitoken',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteApiToken',
    full_name='github.com.metaprov.modelaapi.services.apitoken.v1.ApiTokenService.DeleteApiToken',
    index=4,
    containing_service=None,
    input_type=_DELETEAPITOKENREQUEST,
    output_type=_DELETEAPITOKENRESPONSE,
    serialized_options=b'\202\323\344\223\002&*$/api/{namespace}/v1/apitokens/{name}',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_APITOKENSERVICE)

DESCRIPTOR.services_by_name['ApiTokenService'] = _APITOKENSERVICE

# @@protoc_insertion_point(module_scope)
